% For a denoising problem with a dircetional phantom, Total Generalized 
% Variation(TGV) is compared with Directional Total Generalized 
% Variation(DTGV) regularization.
%
% By Rasmus Dalgas Kongskov, 15/11/2015, DTU Compute

clc,clear,close all; set(0, 'defaultTextInterpreter','latex');
seed = 1405; rng(seed);

%% create and show fibre phantom
N   = 256; % image size
ang = -20;  % agular direction in degrees
I   = fibre_phantom_pa(N,ang);

figure,imagesc(I),colorbar,colormap gray,axis image off;
title('phantom');

%% add white Gaussian noise

pn = 10; % noise-level in percent
b  = I + pn/100*randn(N);
figure,imagesc(b),colorbar,colormap gray,axis image off;
title('noisy data');

A  = 1; % forward operator for denoising problem
AT = 1; % adjoint of forward operator for denoising problem

%% solve L2-TGV problem
lambda  = 0.02*[2,1]; % regularization parameters
Ni      = 1e3;      % maximum number of iterations
tol     = 1e-6;     % stopping criterion tolerance

% DTGV(u) = TGV(u) for parameter choice: a=1 and th=0
a       = 1;
th      = 0;

[u_TGV,on_TGV,sn_TGV,n_TGV] = l2_DTGV(b(:),A,AT,N,lambda,th,a,Ni,tol);

%% solve L2-DTV problem

% estimate angle from noisy image
th    = est_theta_Fourier(b);

lambda  = 0.06*[2,1]; % regularization parameters
Ni      = 1e3;      % maximum number of iterations
tol     = 1e-6;     % stopping criterion tolerance
a       = 0.15;     % width parameter for DTV

[u_DTGV,on_DTGV,sn_DTGV,n_DTGV] = l2_DTGV(b(:),A,AT,N,lambda,th,a,Ni,tol);

%% visualize solutions

figure('position',[300,500,1100,350])
subplot(121),imagesc(u_TGV),colorbar,colormap gray,axis image off,
title(sprintf('$u_{TGV}$, psnr=%.2f',psnr(u_TGV,I)))

subplot(122),imagesc(u_DTGV),colorbar,colormap gray,axis image off
title(sprintf('$u_{DTGV}$, psnr=%.2f',psnr(u_DTGV,I)))
