function I = fibre_phantom(N,ang)
% Creates image piecewise constant phantom with fibre texture along a 
% specific direction. The lines are slightly smoothed in order to make the 
% phantom more realistic.
%
% Input 
% N:    image size
% ang:  angular direction in degrees
% 
% Output
% I:    fibre phantom
%
% By Rasmus Dalgas Kongskov, 15/11/2015, DTU Compute

NN = round(1.45*N);

wst = 5; % width stripes
wsp = 3; % width spaces

dst = randi([-round(wst/2),round(wst/2)],[1,round(NN/(wst+wsp)*1.1)]); % deviation stripes 
dsp = randi([-round(wst/7),round(wst/7)],[1,round(NN/(wst+wsp)*1.1)]); % deviation spaces

stw = wst + dst; % actual stripe width
spw = wsp + dsp; % actual spacing width
sts = [1,cumsum(stw+spw)]; % stripes starting point

% 1D
mis = 0.7; % minimum intensity stripes
mib = 0.2; % minimum intensity background
T  = ones(NN,1)*mib;
for i=1:(length(dst))
    T( (sts(i)+spw(i)):(sts(i)+stw(i)+spw(i)-1) ) = rand*(1-mis)+mis;
end
T = T(1:NN);

% 2D
I1 = repmat(T,1,NN);

% broken lines
I1(1:round(NN*1/2),round(NN*12/20):round(NN*13/20)) = mib;

% rotation
I2 = imrotate(I1,ang,'nearest','crop');

% blur
G  = fspecial('gaussian',[round(NN/10) round(NN/10)],(NN/500));
I3 = imfilter(I2,G,'same');

% crop and scale
I = I3( floor(NN/2-N/2):floor(NN/2+N/2-1), floor(NN/2-N/2):floor(NN/2+N/2-1));
I = (I-min(I(:)))/(max(I(:))-min(I(:)))*(1-mib)+mib;

end