% test direction-estimation on images
%
% By Rasmus Dalgas Kongskov, 05/06/2016, DTU Compute

clc,clear,close all;

%% test-image

seed = 0108; rng(seed);
N    = 256;                     % image-size in pixels
ang  = 70;                      % angle in degrees
im   = fibre_phantom(N,ang);    % fibre-phantom
figure,imagesc(im),colormap gray,axis image off

%% estimate-directions for increasing noise-levels

% noise-levels in percent
pnL = [0,10,20,30,50,80,100];

% estimation parameters
mu  = 10;
pe  = 4;

% allocation
I  = zeros(N,N,length(pnL));
TH = pnL*0;

for i = 1:length(pnL)
    
    % noise
    rng(seed); imn = im + randn(N)*pnL(i)/100; I(:,:,i) = imn;
    
    % estimate angle im1
    th    = est_theta_Fourier(imn);
    TH(i) = th;
    
end

%% visualize results

figure('Position', [300,200,200*length(pnL),200]);

for i = 1:length(pnL)
    
    % plot noisy images and estimate angles as lines
    ang = TH(i)/180*pi; if ang>(pi/2); ang = pi - ang; else ang = -ang; end
    subplot(1,length(pnL),i),imagesc(I(:,:,i)),colormap gray,axis image off
    title([sprintf('$\\theta$ = %.3g$^\\circ$, nl = %.2g',TH(i),pnL(i)),'$\%$']);
    hold on; line([N/2 N/2*(1 + cos(ang)) ],[N/2 N/2*(1 + sin(ang))],'LineWidth',4); hold off
    
end